/**************************************************************************************
Author:         David Szybala
Website:       www.davidszybala.com
Alt Website:  www.twistedgerbil.com
Program:       offset_keys.ms
Date:           07/15/11
Description:   This script will offset animation keys
***************************************************************************************/

try (destroyDialog offset_keys_rollout) catch()


(--put script into local scope
    global offset_keys_rollout
    local offset_keys_ini_file = getDir #plugcfg + "\\OffsetKeys.ini"
    local offset_keys_rollout_pos
    
    /**********************************************************************
    UI creation
    **********************************************************************/
    rollout offset_keys_rollout "Offset Keys"
    (
        groupBox controller_group "Controllers" pos:[5,5] width:150 height:80
            checkbox position_checkbox "Position" pos:[15,25] width:60 height:15 checked:true
            checkbox rotation_checkbox "Rotation" pos:[15,45] width:60 height:15 checked:true
            checkbox scale_checkbox "Scale" pos:[15,65] width:60 height:15 checked:true
        
        groupBox offset_group "Offset" pos:[5,90] width:150 height:70
            radiobuttons offset_mode_radio "" pos:[15,105] labels:#("Constant", "Random") columns:1
            label frame_label "Frames:" pos:[18,140] width:45 height:15
            spinner frame_spinner "" pos:[65,140] width:50 height:15 range:[-9999,9998,5] type:#integer

        groupBox option_group "Options" pos:[5,165] width:150 height:60
            checkbox selection_only_checkbox "Selected Objects Only" pos:[15,185] width:125 height:15 checked:true
            checkbox selected_keys_checkbox "Selected Keys Only" pos:[15,205] width:125 height:15
            
        button offset_key_button "Offset Keys" pos:[5,230] width:150 height:20
        label status_label "INFO: Standing by..." pos:[5,260] width:150 height:15
        
        /**********************************************************************
        UI move event handler. Stores the curent position of the UI
        **********************************************************************/
        on offset_keys_rollout moved pos do
            setIniSetting offset_keys_ini_file "Dialog" "Position" (pos as string)
        
        /**********************************************************************
        Offset button clicked event handler. Offsets the animation keys for selected/all objects
        **********************************************************************/
        on offset_key_button pressed do
        (
            local offset_objects = #()
            local offset_amount = frame_spinner.value
            
            if not position_checkbox.checked and not rotation_checkbox.checked and not scale_checkbox.checked do
            (
                status_label.text = "ERROR: No controller selected"
                return false
            ) --end if
            
            if frame_spinner.value == 0 do
            (
                status_label.text = "ERROR: Offset is 0"
                return false
            ) --end if
            
            if selection_only_checkbox.checked then
                offset_objects = selection as array
            else
                offset_objects = objects
            
            for current in offset_objects do
            (
                if offset_mode_radio.state == 2 do
                    offset_amount = random (-1 * offset_amount) (offset_amount)
                
                if position_checkbox.checked do
                (
                    if (isProperty current "position") do
                    (
                        if selected_keys_checkbox.checked then
                            moveKeys current.position.controller offset_amount #selection
                        else
                            moveKeys current.position.controller offset_amount
                    ) --end if
                ) --end if
                
                if rotation_checkbox.checked do
                (
                    if (isProperty current "rotation") do
                    (
                        if selected_keys_checkbox.checked then
                            moveKeys current.rotation.controller offset_amount #selection
                        else
                            moveKeys current.rotation.controller offset_amount
                    ) --end if
                ) --end if
                
                if scale_checkbox.checked do
                (
                    if (isProperty current "scale") do
                    (
                        if selected_keys_checkbox.checked then
                            moveKeys current.scale.controller offset_amount #selection
                        else
                            moveKeys current.scale.controller offset_amount
                    ) --end if
                ) --end if
            )--end for
            
            status_label.text = "INFO: Offset complete"
        )--end on
    )--end rollout
    
    offset_keys_rollout_pos = execute (getIniSetting offset_keys_ini_file "Dialog" "Position")
    if offset_keys_rollout_pos == OK do offset_keys_rollout_pos = [100,100]
    if offset_keys_rollout_pos.x > sysinfo.desktopsize.x - 160 do
        offset_keys_rollout_pos.x = sysinfo.desktopsize.x - 165
    if offset_keys_rollout_pos.y > sysinfo.desktopsize.y - 335 do
        offset_keys_rollout_pos.y = sysinfo.desktopsize.y - 335
    if offset_keys_rollout_pos.x < 0 do offset_keys_rollout_pos.x = 0 
    if offset_keys_rollout_pos.y < 0 do offset_keys_rollout_pos.y = 0
    createDialog offset_keys_rollout 160 275 offset_keys_rollout_pos.x offset_keys_rollout_pos.y
)--end local scope
